@@ -217,7 +217,8 @@ but users won't be able to add new likes."),
             instance = model.objects.get(id=self.id)
         return instance
 
-    def get_parent(self):
+    @classmethod
+    def get_parent(self, cls):
         """
         Since this is an abstract class, it's proving difficult to
         get the ancestor class in case of multile inheritance.
@@ -229,11 +230,6 @@ but users won't be able to add new likes."),
             def get_parent(self):
                 return MyModelBase
         """
-        #model = type(self)
-        #parents = list(self._meta.get_parent_list())
-        #if any(parents):
-        #    return parents[0]
-        #return model
         raise Exception('Not implemented!')
 
     def get_absolute_url(self):
