@@ -1,13 +1,5 @@
 from django.conf.urls.defaults import patterns, url
 
-from tastypie.api import Api
-
-from molo.api import ModelBaseResource
-
-
-v1_api = Api(api_name='v1')
-v1_api.register(ModelBaseResource())
-
 
 urlpatterns = patterns(
     '',
